@@ -43,6 +43,9 @@ class Settings { /* {{{ */
 	// Restricted access: only allow users to log in if they have an entry in
 	// the local database (irrespective of successful authentication with LDAP).
 	var $_restricted = true;
+	// abitray string used for creation of unique identifiers (e.g. the form
+	// key created by createFormKey())
+	var $_encryptionKey = '';
 	// Strict form checking
 	var $_strictFormCheck = false;
 	// Path to where letoDMS is located
@@ -60,6 +63,8 @@ class Settings { /* {{{ */
 	var $_stagingDir = null;
 	// Where the lucene fulltext index is saved
 	var $_luceneDir = null;
+	// Where the stop word file is located
+	var $_stopWordsFile = null;
 	// enable/disable lucene fulltext search
 	var $_enableFullSearch = true;
 	// contentOffsetDirTo
@@ -251,6 +256,7 @@ class Settings { /* {{{ */
 		$this->_enableUsersView = Settings::boolVal($tab["enableUsersView"]);
 		$this->_enableFolderTree = Settings::boolVal($tab["enableFolderTree"]);
 		$this->_enableFullSearch = Settings::boolVal($tab["enableFullSearch"]);
+		$this->_stopWordsFile = strval($tab["stopWordsFile"]);
 		$this->_expandFolderTree = intval($tab["expandFolderTree"]);
 
 		// XML Path: /configuration/site/calendar
@@ -278,6 +284,7 @@ class Settings { /* {{{ */
 		$tab = $node[0]->attributes();
 		$this->_enableGuestLogin = Settings::boolVal($tab["enableGuestLogin"]);
 		$this->_enablePasswordForgotten = Settings::boolVal($tab["enablePasswordForgotten"]);
+		$this->_encryptionKey = strval($tab["encryptionKey"]);
 		$this->_restricted = Settings::boolVal($tab["restricted"]);
 		$this->_enableUserImage = Settings::boolVal($tab["enableUserImage"]);
 		$this->_disableSelfEdit = Settings::boolVal($tab["disableSelfEdit"]);
@@ -421,7 +428,7 @@ class Settings { /* {{{ */
 		$node = $rootNode->xpath($parentNodeName . '/' . $name);
 
 		if (empty($node)) {
-			$node = $xml->xpath($parentNodeName);
+			$node = $rootNode->xpath($parentNodeName);
 			$node = $node[0]->addChild($name);
 		} else {
 			$node = $node[0];
@@ -464,6 +471,7 @@ class Settings { /* {{{ */
     $this->setXMLAttributValue($node, "enableFolderTree", $this->_enableFolderTree);
     $this->setXMLAttributValue($node, "enableFullSearch", $this->_enableFullSearch);
     $this->setXMLAttributValue($node, "expandFolderTree", $this->_expandFolderTree);
+    $this->setXMLAttributValue($node, "stopWordsFile", $this->_stopWordsFile);
 
     // XML Path: /configuration/site/calendar
     $node = $this->getXMLNode($xml, '/configuration/site', 'calendar');
@@ -488,6 +496,7 @@ class Settings { /* {{{ */
     $node = $this->getXMLNode($xml, '/configuration/system', 'authentication');
     $this->setXMLAttributValue($node, "enableGuestLogin", $this->_enableGuestLogin);
     $this->setXMLAttributValue($node, "enablePasswordForgotten", $this->_enablePasswordForgotten);
+    $this->setXMLAttributValue($node, "encryptionKey", $this->_encryptionKey);
     $this->setXMLAttributValue($node, "restricted", $this->_restricted);
     $this->setXMLAttributValue($node, "enableUserImage", $this->_enableUserImage);
     $this->setXMLAttributValue($node, "disableSelfEdit", $this->_disableSelfEdit);
@@ -598,21 +607,6 @@ class Settings { /* {{{ */
 			if (file_exists($configDir."/settings.xml"))
 				return $configDir."/settings.xml";
 		}
-/*
-		// Search config file
-		$_tmp = dirname($_SERVER['SCRIPT_FILENAME']);
-		if(is_link($_tmp)) {
-			$_arr = preg_split('/\//', $_tmp);
-			array_pop($_arr);
-
-			$configFilePath = implode('/', $_arr)."/conf/settings.xml";
-		} else {
-			if (file_exists("../conf/settings.xml"))
-				$configFilePath = "../conf/settings.xml";
-			else if (file_exists("conf/settings.xml"))
-				$configFilePath = "conf/settings.xml";
-		}
-*/
 		return $configFilePath;
 	} /* }}} */
 
@@ -821,7 +815,7 @@ class Settings { /* {{{ */
 		// $this->_ADOdbPath
 		$bCheckDB = true;
 		if($this->_ADOdbPath) {
-			if (!file_exists($this->_ADOdbPath."adodb/adodb.inc.php")) {
+			if (!file_exists($this->_ADOdbPath."/adodb/adodb.inc.php")) {
 				$bCheckDB = false;
 				if (file_exists($rootDir."adodb/adodb.inc.php")) {
 					$result["ADOdbPath"] = array(
