@@ -34,6 +34,20 @@ CREATE TABLE `tblUsers` (
 
 -- --------------------------------------------------------
 
+-- 
+-- Table structure for table `tblUserPasswordRequest`
+-- 
+
+CREATE TABLE `tblUserPasswordRequest` (
+  `id` int(11) NOT NULL auto_increment,
+  `userID` int(11) NOT NULL default '0',
+  `hash` varchar(50) default NULL,
+  `date` datetime NOT NULL default '0000-00-00 00:00:00',
+  PRIMARY KEY  (`id`)
+) ENGINE=MyISAM DEFAULT CHARSET=utf8;
+
+-- --------------------------------------------------------
+
 -- 
 -- Table structure for table `tblUserImages`
 -- 
@@ -56,6 +70,7 @@ CREATE TABLE `tblFolders` (
   `id` int(11) NOT NULL auto_increment,
   `name` varchar(70) default NULL,
   `parent` int(11) default NULL,
+  `folderList` text NOT NULL,
   `comment` text,
   `date` int(12) default NULL,
   `owner` int(11) default NULL,
@@ -136,7 +151,7 @@ CREATE TABLE `tblDocumentContent` (
   `dir` varchar(255) NOT NULL default '',
   `orgFileName` varchar(150) NOT NULL default '',
   `fileType` varchar(10) NOT NULL default '',
-  `mimeType` varchar(70) NOT NULL default '',
+  `mimeType` varchar(100) NOT NULL default '',
   UNIQUE (`document`,`version`)
 ) ENGINE=MyISAM DEFAULT CHARSET=utf8;
 
@@ -171,7 +186,7 @@ CREATE TABLE `tblDocumentFiles` (
   `dir` varchar(255) NOT NULL default '',
   `orgFileName` varchar(150) NOT NULL default '',
   `fileType` varchar(10) NOT NULL default '',
-  `mimeType` varchar(70) NOT NULL default '',  
+  `mimeType` varchar(100) NOT NULL default '',  
   PRIMARY KEY  (`id`)
 ) ENGINE=MyISAM DEFAULT CHARSET=utf8;
 
@@ -435,8 +450,8 @@ CREATE TABLE `tblVersion` (
 -- Initial content for database
 --
 
-INSERT INTO tblFolders VALUES (1, 'DMS', 0, 'DMS root', UNIX_TIMESTAMP(), 1, 0, 2, 0);
 INSERT INTO tblUsers VALUES (1, 'admin', '21232f297a57a5a743894a0e4a801fc3', 'Administrator', 'address@server.com', '', '', '', 1, 0);
 INSERT INTO tblUsers VALUES (2, 'guest', NULL, 'Guest User', NULL, '', '', '', 2, 0);
-INSERT INTO tblVersion VALUES (NOW(), 3, 2, 0);
+INSERT INTO tblFolders VALUES (1, 'DMS', 0, '', 'DMS root', UNIX_TIMESTAMP(), 1, 0, 2, 0);
+INSERT INTO tblVersion VALUES (NOW(), 3, 3, 0);
 INSERT INTO tblCategory VALUES (0, '');
