@@ -35,6 +35,11 @@ if (!$user->isAdmin() && ($settings->_disableSelfEdit)) {
 $fullname = $_POST["fullname"];
 $email    = $_POST["email"];
 $comment  = $_POST["comment"];
+$current_pwd  = $_POST["currentpwd"];
+
+if($user->getPwd() != md5($current_pwd)) {
+	UI::exitError(getMLText("edit_user_details"),getMLText("password_wrong"));
+}
 
 if (isset($_POST["pwd"]) && ($_POST["pwd"] != ""))
 	$user->setPwd(md5($_POST["pwd"]));
@@ -48,7 +53,7 @@ if ($user->getEmail() != $email)
 if ($user->getComment() != $comment)
 	$user->setComment($comment);
 
-if (is_uploaded_file($_FILES["userfile"]["tmp_name"]) && $_FILES["userfile"]["size"] > 0 && $_FILES['userfile']['error']==0)
+if (isset($_FILES["userfile"]) && is_uploaded_file($_FILES["userfile"]["tmp_name"]) && $_FILES["userfile"]["size"] > 0 && $_FILES['userfile']['error']==0)
 {
 	$lastDotIndex = strrpos(basename($_FILES["userfile"]["name"]), ".");
 	$fileType = substr($_FILES["userfile"]["name"], $lastDotIndex);
