@@ -3,6 +3,7 @@
 //    Copyright (C) 2002-2005  Markus Westphal
 //    Copyright (C) 2006-2008 Malcolm Cowe
 //    Copyright (C) 2010 Matteo Lucarelli
+//    Copyright (C) 2010-2012 Uwe Steinmann
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -31,12 +32,16 @@ if (!$user->isAdmin()) {
 }
 
 if (isset($_POST["action"])) $action=$_POST["action"];
-else if (isset($_GET["action"])) $action=$_GET["action"];
 else $action=NULL;
 
 //Neuen Benutzer anlegen --------------------------------------------------------------------------
 if ($action == "adduser") {
 	
+	/* Check if the form data comes for a trusted request */
+	if(!checkFormKey('adduser')) {
+		UI::exitError(getMLText("admin_tools"),getMLText("invalid_request_token"));
+	}
+
 	$login   = $_POST["login"];
 	$name    = $_POST["name"];
 	$email   = $_POST["email"];
@@ -98,12 +103,14 @@ if ($action == "adduser") {
 //Benutzer lschen --------------------------------------------------------------------------------
 else if ($action == "removeuser") {
 
+	/* Check if the form data comes for a trusted request */
+	if(!checkFormKey('removeuser')) {
+		UI::exitError(getMLText("admin_tools"),getMLText("invalid_request_token"));
+	}
+
 	if (isset($_POST["userid"])) {
 		$userid = $_POST["userid"];
 	}
-	else if (isset($_GET["userid"])) {
-		$userid = $_GET["userid"];
-	}
 
 	if (!isset($userid) || !is_numeric($userid) || intval($userid)<1) {
 		UI::exitError(getMLText("admin_tools"),getMLText("invalid_user_id"));
@@ -134,6 +141,11 @@ else if ($action == "removeuser") {
 //Benutzer bearbeiten -----------------------------------------------------------------------------
 else if ($action == "edituser") {
 
+	/* Check if the form data comes for a trusted request */
+	if(!checkFormKey('edituser')) {
+		UI::exitError(getMLText("admin_tools"),getMLText("invalid_request_token"));
+	}
+
 	if (!isset($_POST["userid"]) || !is_numeric($_POST["userid"]) || intval($_POST["userid"])<1) {
 		UI::exitError(getMLText("admin_tools"),getMLText("invalid_user_id"));
 	}
