@@ -3,6 +3,7 @@
 //    Copyright (C) 2002-2005  Markus Westphal
 //    Copyright (C) 2006-2008 Malcolm Cowe
 //    Copyright (C) 2010 Matteo Lucarelli
+//    Copyright (C) 2010-2012 Uwe Steinmann
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -106,8 +107,7 @@ UI::contentContainerStart();
 <tr>
 <td>
 
-<?php echo getMLText("selection")?>:
-<select onchange="showUser(this)" id="selector">
+<?php echo getMLText("selection")?>:<select onchange="showUser(this)" id="selector">
 <option value="-1"><?php echo getMLText("choose_group")?>
 <option value="0"><?php echo getMLText("add_group")?>
 <?php
@@ -126,7 +126,8 @@ UI::contentContainerStart();
 
 	<td id="keywords0" style="display : none;">
 	
-	<form action="../op/op.GroupMgr.php" name="form0_1" onsubmit="return checkForm1('0');">
+	<form action="../op/op.GroupMgr.php" name="form0_1" method="post" onsubmit="return checkForm1('0');">
+  <?php echo createHiddenFieldWithKey('addgroup'); ?>
 	<input type="Hidden" name="action" value="addgroup">
 	<table>
 		<tr>
@@ -161,7 +162,8 @@ UI::contentContainerStart();
 	<?php	UI::contentSubHeading(getMLText("edit_group"));?>
 		
 	
-	<form action="../op/op.GroupMgr.php" name="form<?php print $group->getID();?>_1" onsubmit="return checkForm1('<?php print $group->getID();?>');">
+	<form action="../op/op.GroupMgr.php" name="form<?php print $group->getID();?>_1" method="post" onsubmit="return checkForm1('<?php print $group->getID();?>');">
+	<?php echo createHiddenFieldWithKey('editgroup'); ?>
 	<input type="Hidden" name="groupid" value="<?php print $group->getID();?>">
 	<input type="Hidden" name="action" value="editgroup">
 	<table>
@@ -195,8 +197,8 @@ UI::contentContainerStart();
 					print "<td>" . htmlspecialchars($member->getFullName()) . "</td>";
 					print "<td>" . ($group->isMember($member,true)?getMLText("manager"):"&nbsp;") . "</td>";
 					print "<td align=\"right\"><ul class=\"actions\">";
-					print "<li><a href=\"../op/op.GroupMgr.php?groupid=". $group->getID() . "&userid=".$member->getID()."&action=rmmember\">".getMLText("delete")."</a>";
-					print "<li><a href=\"../op/op.GroupMgr.php?groupid=". $group->getID() . "&userid=".$member->getID()."&action=tmanager\">".getMLText("toggle_manager")."</a>";
+					print "<li><form action=\"../op/op.GroupMgr.php\" method=\"post\"><input type=\"hidden\" name=\"action\" value=\"rmmember\" /><input type=\"hidden\" name=\"groupid\" value=\"".$group->getID()."\" /><input type=\"hidden\" name=\"userid\" value=\"".$member->getID()."\" />".createHiddenFieldWithKey('rmmember')."<input type=\"submit\" value=\"".getMLText("delete")."\" /></form>";
+					print "<li><form action=\"../op/op.GroupMgr.php\" method=\"post\"><input type=\"hidden\" name=\"groupid\" value=\"".$group->getID()."\" /><input type=\"hidden\" name=\"action\" value=\"tmanager\" /><input type=\"hidden\" name=\"userid\" value=\"".$member->getID()."\" />".createHiddenFieldWithKey('tmanager')."<input type=\"submit\" value=\"".getMLText("toggle_manager")."\" /></form>";
 					print "</td></tr>";
 				}
 			}
@@ -210,7 +212,8 @@ UI::contentContainerStart();
 		
 		?>
 		
-		<form action="../op/op.GroupMgr.php" method=POST name="form<?php print $group->getID();?>_2" onsubmit="return checkForm2('<?php print $group->getID();?>');">
+		<form action="../op/op.GroupMgr.php" method="POST" name="form<?php print $group->getID();?>_2" onsubmit="return checkForm2('<?php print $group->getID();?>');">
+		<?php echo createHiddenFieldWithKey('addmember'); ?>
 		<input type="Hidden" name="action" value="addmember">
 		<input type="Hidden" name="groupid" value="<?php print $group->getID();?>">
 		<table width="100%">
@@ -221,7 +224,7 @@ UI::contentContainerStart();
 						<?php
 							foreach ($allUsers as $currUser)
 								if (!$group->isMember($currUser))
-									print "<option value=\"".$currUser->getID()."\">" . htmlspecialchars($currUser->getFullName()) . "\n";
+									print "<option value=\"".$currUser->getID()."\">" . htmlspecialchars($currUser->getLogin()." - ".$currUser->getFullName()) . "\n";
 						?>
 					</select>
 				</td>
