@@ -2,7 +2,7 @@
 //    MyDMS. Document Management System
 //    Copyright (C) 2002-2005  Markus Westphal
 //    Copyright (C) 2006-2008 Malcolm Cowe
-//    Copyright (C) 2006-2008 Malcolm Cowe
+//    Copyright (C) 2010-2012 Uwe Steinmann
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ if (!isset($_GET["userid"]) || !is_numeric($_GET["userid"]) || intval($_GET["use
 	UI::exitError(getMLText("rm_user"),getMLText("invalid_user_id"));
 }
 
-$userid = $_GET["userid"];
+$userid = intval($_GET["userid"]);
 $currUser = $dms->getUser($userid);
 
 if ($userid==$user->getID()) {
@@ -53,6 +53,7 @@ UI::contentContainerStart();
 <form action="../op/op.UsrMgr.php" name="form1" method="POST">
 <input type="Hidden" name="userid" value="<?php print $userid;?>">
 <input type="Hidden" name="action" value="removeuser">
+<?php echo createHiddenFieldWithKey('removeuser'); ?>
 <p>
 <?php printMLText("confirm_rm_user", array ("username" => htmlspecialchars($currUser->getFullName())));?>
 </p>
@@ -67,7 +68,7 @@ UI::contentContainerStart();
 			continue;
 
 		if (isset($_GET["userid"]) && $currUser->getID()==$_GET["userid"]) $selected=$count;
-		print "<option value=\"".$currUser->getID()."\">" . htmlspecialchars($currUser->getLogin());
+		print "<option value=\"".$currUser->getID()."\">" . htmlspecialchars($currUser->getLogin()." - ".$currUser->getFullName());
 	}
 ?>
 </select>
