@@ -26,6 +26,10 @@ if (!$user->isAdmin()) {
 	UI::exitError(getMLText("admin_tools"),getMLText("access_denied"));
 }
 
+/* Set an encryption key if is not set */
+if(!trim($settings->_encryptionKey))
+	$settings->_encryptionKey = md5(uniqid());
+
 UI::htmlStartPage(getMLText("admin_tools"));
 UI::globalNavigation();
 UI::pageNavigation(getMLText("admin_tools"), "admin_tools");
@@ -150,6 +154,10 @@ if(!is_writeable($settings->_configFilePath)) {
         <td><?php printMLText("settings_enableFullSearch");?>:</td>
         <td><input name="enableFullSearch" type="checkbox" <?php if ($settings->_enableFullSearch) echo "checked" ?> /></td>
       </tr>
+      <tr title="<?php printMLText("settings_stopWordsFile_desc");?>">
+        <td><?php printMLText("settings_stopWordsFile");?>:</td>
+        <td><input name="stopWordsFile" value="<?php echo $settings->_stopWordsFile; ?>" size="100" /></td>
+      </tr>
       <tr title="<?php printMLText("settings_enableFolderTree_desc");?>">
         <td><?php printMLText("settings_enableFolderTree");?>:</td>
         <td><input name="enableFolderTree" type="checkbox" <?php if ($settings->_enableFolderTree) echo "checked" ?> /></td>
@@ -269,6 +277,10 @@ if(!is_writeable($settings->_configFilePath)) {
         <td><?php printMLText("settings_enablePasswordForgotten");?>:</td>
         <td><input name="enablePasswordForgotten" type="checkbox" <?php if ($settings->_enablePasswordForgotten) echo "checked" ?> /></td>
       </tr>
+      <tr title="<?php printMLText("settings_encryptionKey_desc");?>">
+        <td><?php printMLText("settings_encryptionKey");?>:</td>
+        <td><input name="encryptionKey" value="<?php echo $settings->_encryptionKey; ?>" size="32" /></td>
+      </tr>
 
       <!-- TODO Connectors -->
 
